-- $Id: Atlas_OutdoorRaids.lua 11 2016-05-13 05:34:36Z arith $
--[[

	Atlas, a World of Warcraft instance map browser
	Copyright 2005 ~ 2010 - Dan Gilbert <dan.b.gilbert@gmail.com>
	Copyright 2010 - Lothaer <lothayer@gmail.com>, Atlas Team
	Copyright 2011 ~ 2016 - Arith Hsu, Atlas Team <atlas.addon@gmail.com>

	This file is part of Atlas.

	Atlas is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Atlas is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Atlas; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

local BZ = Atlas_GetLocaleLibBabble("LibBabble-SubZone-3.0");
local AL = LibStub("AceLocale-3.0"):GetLocale("Atlas_OutdoorRaids");
local ALC = LibStub("AceLocale-3.0"):GetLocale("Atlas");
local ALIL = Atlas_IngameLocales;

local BLUE = "|cff6666ff";
local GREN = "|cff66cc33";
local LBLU = "|cff33cccc";
local _RED = "|cffcc3333";
local ORNG = "|cffcc9933";
local PINK = "|ccfcc33cc";
local PURP = "|cff9900ff";
local WHIT = "|cffffffff";
local YLOW = "|cffcccc33";
local INDENT = "      ";

local myCategory = AL["Outdoor Raid Encounters"];

local myData = {
	OR_DoomLordKazzak = {
		ZoneName = { Atlas_GetBossName("Doom Lord Kazzak") };
		Location = { BZ["Hellfire Peninsula"] };
		LevelRange = "70+";
		PlayerLimit = "40";
		{ WHIT.."1) "..Atlas_GetBossName("Doom Lord Kazzak"), 10001 };
		{ WHIT.."2) "..BZ["Invasion Point: Annihilator"], 10002 };
		{ WHIT.."3) "..BZ["Forge Camp: Rage"], 10003 };
		{ WHIT.."4) "..BZ["Forge Camp: Mageddon"], 10004 };
		{ WHIT.."5) "..BZ["Thrallmar"], 10005 };
	};
	OR_Doomwalker = {
		ZoneName = { Atlas_GetBossName("Doomwalker") };
		Location = { BZ["Shadowmoon Valley"] };
		LevelRange = "70+";
		PlayerLimit = "40";
		{ WHIT.."1) "..Atlas_GetBossName("Doomwalker"), 10001 };
	};
	OR_Draenor = {
		ZoneName = { AL["Draenor World Bosses"] };
		Location = { BZ["Draenor"] };
		LevelRange = "100+";
		PlayerLimit = "--";
		JournalInstanceID = "557";
		{ WHIT.." 1) "..Atlas_GetBossName("Drov the Ruiner", 1291) };
		{ WHIT..INDENT..Atlas_GetBossName("Frenzied Rumbler", 1291, 2) };
		{ WHIT.." 2) "..Atlas_GetBossName("Tarlna the Ageless", 1211) };
		{ WHIT..INDENT..Atlas_GetBossName("Giant Lasher", 1211, 3) };
		{ WHIT..INDENT..Atlas_GetBossName("Untamed Mandragora", 1211, 2) };
		{ WHIT.." 3) "..Atlas_GetBossName("Rukhmar", 1262) };
		{ WHIT.." 4) "..Atlas_GetBossName("Supreme Lord Kazzak", 1452) };
	};
	OR_Pandaria = {
		ZoneName = { AL["Pandaria World Bosses"] };
		Location = { BZ["Pandaria"] };
		LevelRange = "90+";
		PlayerLimit = "--";
		JournalInstanceID = "322";
		{ WHIT.." 1) "..Atlas_GetBossName("Nalak, The Storm Lord", 814) };
		{ WHIT.." 2) "..Atlas_GetBossName("Oondasta", 826) };
		{ WHIT.." 3) "..Atlas_GetBossName("Sha of Anger", 691) };
		{ WHIT.." 4) "..Atlas_GetBossName("Salyis's Warband", 725) };
		{ WHIT..INDENT..Atlas_GetBossName("Galleon", 725, 1) };
		{ WHIT..INDENT..Atlas_GetBossName("Chief Salyis", 725, 2) };
		{ WHIT.." 5) "..Atlas_GetBossName("Ordos, Fire-God of the Yaungol", 861) };
		{ WHIT.." 6) "..ALIL["The August Celestials"] };
		{ WHIT..INDENT..Atlas_GetBossName("Chi-Ji, The Red Crane", 857) };
		{ WHIT..INDENT..Atlas_GetBossName("Niuzao, The Black Ox", 859) };
		{ WHIT..INDENT..Atlas_GetBossName("Xuen, The White Tiger", 860) };
		{ WHIT..INDENT..Atlas_GetBossName("Yu'lon, The Jade Serpent", 858) };
	};
	OR_Skettis = {
		ZoneName = { BZ["Skettis"] };
		Location = { BZ["Blackwind Valley"]..", "..BZ["Terokkar Forest"] };
		LevelRange = "70+";
		PlayerLimit = "40";
		{ WHIT.."1) "..BZ["Blackwind Landing"], 10001 };
		{ WHIT..INDENT..AL["Sky Commander Adaris"] };
		{ WHIT..INDENT..AL["Sky Sergeant Doryn"] };
		{ WHIT..INDENT..AL["Skyguard Handler Deesak"] };
		{ WHIT..INDENT..AL["Severin <Skyguard Medic>"] };
		{ WHIT..INDENT..AL["Grella <Skyguard Quartermaster>"] };
		{ WHIT..INDENT..AL["Hazzik"] };
		{ WHIT.."2) "..AL["Ancient Skull Pile"], 10002 };
		{ WHIT..INDENT..AL["Terokk"].." ("..ALC["Summon"]..")" };
		{ WHIT.."3) "..AL["Sahaak <Keeper of Scrolls>"], 10003 };
		{ WHIT.."4) "..AL["Skyguard Prisoner"].." ("..ALC["Random"]..")", 10004 };
		{ WHIT.."5) "..AL["Talonpriest Ishaal"], 10005 };
		{ WHIT.."6) "..AL["Talonpriest Skizzik"], 10006 };
		{ WHIT.."7) "..AL["Talonpriest Zellek"], 10007 };
		{ WHIT.."8) "..AL["Hazzik's Package"], 10008 };
		{ WHIT.."9) "..ALC["Graveyard"], 10009 };
		{ GREN.."1') "..AL["Skull Pile"], 10010 };
		{ GREN..INDENT..AL["Darkscreecher Akkarai"].." ("..ALC["Summon"]..")" };
		{ GREN..INDENT..AL["Gezzarak the Huntress"].." ("..ALC["Summon"]..")" };
		{ GREN..INDENT..AL["Karrog"].." ("..ALC["Summon"]..")" };
		{ GREN..INDENT..AL["Vakkiz the Windrager"].." ("..ALC["Summon"]..")" };
	};
};

Atlas_RegisterPlugin("Atlas_OutdoorRaids", myCategory, myData);
